summaryrefslogtreecommitdiffstats
path: root/models/issue_stopwatch.go
diff options
context:
space:
mode:
authorLunny Xiao <xiaolunwen@gmail.com>2017-10-02 00:52:35 +0800
committerLauris BH <lauris@nix.lv>2017-10-01 19:52:35 +0300
commita8717e5e3ace4dd226547faae9c3a44616bbf6f0 (patch)
tree524dc024dec64131406486556951a53655ad8510 /models/issue_stopwatch.go
parent1ad902d5298202d5be14fd5a9c8ed6ce781a23c8 (diff)
downloadgitea-a8717e5e3ace4dd226547faae9c3a44616bbf6f0.tar.gz
gitea-a8717e5e3ace4dd226547faae9c3a44616bbf6f0.zip
Use AfterLoad instead of AfterSet on Structs (#2628)
* use AfterLoad instead of AfterSet on Structs * fix the comments on AfterLoad * fix the comments on action AfterLoad
Diffstat (limited to 'models/issue_stopwatch.go')
-rw-r--r--models/issue_stopwatch.go12
1 files changed, 3 insertions, 9 deletions
diff --git a/models/issue_stopwatch.go b/models/issue_stopwatch.go
index 3b5b4d57f3..b136c511f4 100644
--- a/models/issue_stopwatch.go
+++ b/models/issue_stopwatch.go
@@ -7,8 +7,6 @@ package models
import (
"fmt"
"time"
-
- "github.com/go-xorm/xorm"
)
// Stopwatch represents a stopwatch for time tracking.
@@ -26,13 +24,9 @@ func (s *Stopwatch) BeforeInsert() {
s.CreatedUnix = time.Now().Unix()
}
-// AfterSet is invoked from XORM after setting the value of a field of this object.
-func (s *Stopwatch) AfterSet(colName string, _ xorm.Cell) {
- switch colName {
-
- case "created_unix":
- s.Created = time.Unix(s.CreatedUnix, 0).Local()
- }
+// AfterLoad is invoked from XORM after setting the values of all fields of this object.
+func (s *Stopwatch) AfterLoad() {
+ s.Created = time.Unix(s.CreatedUnix, 0).Local()
}
func getStopwatch(e Engine, userID, issueID int64) (sw *Stopwatch, exists bool, err error) {